//********************************************************
//
//               Ansi/Unicode line I/O
//
//          Copyright  2005 Jaroslav Klima
//
//********************************************************

#include "ConfigString.h"
#include "stdafx.h"

bool LineToFile(FILE* f, const char* const s, int eol, size_t length)
{
    // check if the pointer is valid
    if (!s)
    {
        return false;
    };
    
    // calculate the string's length
    if (length==-1)
    {
        length = strlen(s);
    };
    
    // write the string to the file
    size_t n = fwrite(s, sizeof(char), length, f);
            
    // write line break to the file
    fputc(eol, f);
            
    // return whether the write operation was successful
    return (n == length);
};

bool LineToFile(FILE* f, const wchar_t* const s, wint_t eol, size_t length)
{
    // check if the pointer is valid
    if (!s)
    {
        return false;
    };
        
    // calculate the string's length
    if (length==-1)
    {
        length = wcslen(s);
    };    
    
    // write the string to the file
    size_t n = fwrite(s, sizeof(wchar_t), length, f);
            
    // write line break to the file
    fputwc(eol, f);
            
    // return whether the write operation was successful
    return (n == length);
};





bool LineFromFile(FILE* f, std::string& s, int eol, int eof)
{
    // reset string
    s.clear();
    
    // read one char at a time
    while (true)
    {
        // read char
        int c = fgetc(f);        
        
        // check for EOF
        if (c == eof || c == EOF) return false;

        // check for EOL
        if (c == eol) return true;

        // append this character to the string
        s += c;
    };
};



bool LineFromFile(FILE* f, std::wstring& s, wint_t eol, wint_t eof)
{
    // reset string
    s.clear();
    
    // read one wide char at a time
    while (true)
    {
        // read wide char
        wint_t c = fgetwc(f);
        
        // check for EOF
        if (c == eof || c == WEOF) return false;

        // check for EOL
        if (c == eol) return true;

        // append the wide character to the string        
        s += c;
    };
};


