//********************************************************
//
//               Ansi/Unicode line I/O
//
//          Copyright  2005 Jaroslav Klima
//
//********************************************************

#ifndef _CONFIGSTRING_H_
#define _CONFIGSTRING_H_

#pragma once

#include <stdio.h>
#include <string>
#include <tchar.h>

//---------------------------------------------
// Functions for writing lines of text to files
//---------------------------------------------

// To write an ANSI zero-terminated string (please consider using STL instead)
bool LineToFile(FILE* f, const char* const s, int eol = '\n', size_t length = -1);

// To write a Unicode zero-terminated string (please consider using STL instead)
bool LineToFile(FILE* f, const wchar_t* const s, wint_t eol = L'\n', size_t length = -1);

// To write an ANSI STL string
inline bool LineToFile(FILE* f, const std::string& s, int eol = '\n')
{
    return LineToFile(f, s.c_str(), eol, s.size());
};

// To write a Unicode STL string
inline bool LineToFile(FILE* f, const std::wstring& s, wint_t eol = L'\n')
{
    return LineToFile(f, s.c_str(), eol, s.size());
};



//-----------------------------------------------
// Functions for reading lines of text from files
//-----------------------------------------------

// To read an ANSI string
bool LineFromFile(FILE* f, std::string& s, int eol = '\n', int oef = EOF);

// To read a Unicode string
bool LineFromFile(FILE* f, std::wstring& s, wint_t eol = '\n', wint_t oef = WEOF);

#endif
